
# Slot: required


true means that the slot must be present in the loaded definition

URI: [linkml:required](https://w3id.org/linkml/required)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
